Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Port string
Environment string
BaseURL string
DatabaseURL string
JWTSecret string
LicenseSigningKey string
GitHubClientID string
GitHubClientSecret string
GoogleClientID string
GoogleClientSecret string
StripeSecretKey string
StripeWebhookSecret string
PayPalClientID string
PayPalClientSecret string
PayPalWebhookID string
PayPalSandbox bool
WebhookMaxAttempts int
WebhookRetryInterval string
WebhookHTTPTimeout string
QuotaWarningThreshold float64
SMTPHost string
SMTPPort string
SMTPUsername string
SMTPPassword string
SMTPFrom string
RedisURL string
RateLimitAPI int
RateLimitAdmin int
AdminEmails []string
}
func (*Config) IsAdminEmail ¶
IsAdminEmail checks if an email is in the ADMIN_EMAILS list. Used for backward compatibility and initial setup bootstrap. In normal operation, admin status is determined by the user's role in the database.
func (*Config) IsDevLoginAllowed ¶
func (*Config) IsProduction ¶
func (*Config) ValidateSecurityDefaults ¶
ValidateSecurityDefaults checks for common misconfigurations that could lead to security vulnerabilities in production deployments. Returns a list of warnings (non-fatal) and errors (fatal).
Click to show internal directories.
Click to hide internal directories.